@@ -32,7 +32,7 @@ use bonsaidb_utils::fast_async_lock;
 use byteorder::{BigEndian, ByteOrder};
 use itertools::Itertools;
 use nebari::{
-    io::fs::StdFile,
+    io::any::AnyFile,
     tree::{
         AnyTreeRoot, BorrowByteRange, KeyEvaluation, Root, TreeRoot, U64Range, Unversioned,
         Versioned,
@@ -60,6 +60,41 @@ pub mod keyvalue;
 pub mod pubsub;
 
 /// A local, file-based database.
+///
+/// ## Using `Database` to create a single database
+///
+/// `Database`provides an easy mechanism to open and access a single database:
+///
+/// ```rust
+/// // `bonsaidb_core` is re-exported to `bonsaidb::core` or `bonsaidb_local::core`.
+/// use bonsaidb_core::schema::Collection;
+/// // `bonsaidb_local` is re-exported to `bonsaidb::local` if using the omnibus crate.
+/// use bonsaidb_local::{
+///     config::{Builder, StorageConfiguration},
+///     Database,
+/// };
+/// use serde::{Deserialize, Serialize};
+///
+/// #[derive(Debug, Serialize, Deserialize, Collection)]
+/// #[collection(name = "blog-posts")]
+/// # #[collection(core = bonsaidb_core)]
+/// struct BlogPost {
+///     pub title: String,
+///     pub contents: String,
+/// }
+///
+/// # async fn test_fn() -> Result<(), bonsaidb_core::Error> {
+/// let db = Database::open::<BlogPost>(StorageConfiguration::new("my-db.bonsaidb")).await?;
+/// #     Ok(())
+/// # }
+/// ```
+///
+/// Under the hood, this initializes a [`Storage`] instance pointing at
+/// "./my-db.bonsaidb". It then returns (or creates) a database named "default"
+/// with the schema `BlogPost`.
+///
+/// In this example, `BlogPost` implements the [`Collection`] trait, and all
+/// collections can be used as a [`Schema`].
 #[derive(Debug)]
 pub struct Database {
     pub(crate) data: Arc<Data>,
@@ -162,7 +197,7 @@ impl Database {
         &self.data.schema
     }
 
-    pub(crate) fn roots(&self) -> &'_ nebari::Roots<StdFile> {
+    pub(crate) fn roots(&self) -> &'_ nebari::Roots<AnyFile> {
         &self.data.context.roots
     }
 
@@ -613,7 +648,7 @@ impl Database {
             .data
             .context
             .roots
-            .transaction::<_, dyn AnyTreeRoot<StdFile>>(&open_trees.trees)?;
+            .transaction::<_, dyn AnyTreeRoot<AnyFile>>(&open_trees.trees)?;
 
         let mut results = Vec::new();
         let mut changed_documents = Vec::new();
@@ -683,7 +718,7 @@ impl Database {
     fn execute_operation(
         &self,
         operation: &Operation,
-        transaction: &mut ExecutingTransaction<StdFile>,
+        transaction: &mut ExecutingTransaction<AnyFile>,
         tree_index_map: &HashMap<String, usize>,
     ) -> Result<OperationResult, Error> {
         match &operation.command {
@@ -710,7 +745,7 @@ impl Database {
     fn execute_update(
         &self,
         operation: &Operation,
-        transaction: &mut ExecutingTransaction<StdFile>,
+        transaction: &mut ExecutingTransaction<AnyFile>,
         tree_index_map: &HashMap<String, usize>,
         header: &Header,
         contents: Vec<u8>,
@@ -769,7 +804,7 @@ impl Database {
     fn execute_insert(
         &self,
         operation: &Operation,
-        transaction: &mut ExecutingTransaction<StdFile>,
+        transaction: &mut ExecutingTransaction<AnyFile>,
         tree_index_map: &HashMap<String, usize>,
         id: Option<u64>,
         contents: Vec<u8>,
@@ -811,7 +846,7 @@ impl Database {
     fn execute_delete(
         &self,
         operation: &Operation,
-        transaction: &mut ExecutingTransaction<StdFile>,
+        transaction: &mut ExecutingTransaction<AnyFile>,
         tree_index_map: &HashMap<String, usize>,
         header: &Header,
     ) -> Result<OperationResult, Error> {
@@ -851,7 +886,7 @@ impl Database {
         &self,
         document_id: &[u8],
         operation: &Operation,
-        transaction: &mut ExecutingTransaction<StdFile>,
+        transaction: &mut ExecutingTransaction<AnyFile>,
         tree_index_map: &HashMap<String, usize>,
     ) -> Result<(), Error> {
         if let Some(unique_views) = self
@@ -884,7 +919,7 @@ impl Database {
     }
 
     fn create_view_iterator<'a, K: for<'k> Key<'k> + 'a>(
-        view_entries: &'a Tree<Unversioned, StdFile>,
+        view_entries: &'a Tree<Unversioned, AnyFile>,
         key: Option<QueryKey<K>>,
         order: Sort,
         limit: Option<usize>,
@@ -990,7 +1025,7 @@ impl Database {
         &self,
         collection: &CollectionName,
         name: S,
-    ) -> Result<TreeRoot<R, StdFile>, Error> {
+    ) -> Result<TreeRoot<R, AnyFile>, Error> {
         let mut tree = R::tree(name);
 
         if let Some(key) = self.collection_encryption_key(collection) {
@@ -1390,19 +1425,19 @@ impl Deref for Context {
 
 #[derive(Debug)]
 pub(crate) struct ContextData {
-    pub(crate) roots: Roots<StdFile>,
+    pub(crate) roots: Roots<AnyFile>,
     key_value_state: Arc<Mutex<keyvalue::KeyValueState>>,
     runtime: tokio::runtime::Handle,
 }
 
-impl Borrow<Roots<StdFile>> for Context {
-    fn borrow(&self) -> &Roots<StdFile> {
+impl Borrow<Roots<AnyFile>> for Context {
+    fn borrow(&self) -> &Roots<AnyFile> {
         &self.data.roots
     }
 }
 
 impl Context {
-    pub(crate) fn new(roots: Roots<StdFile>, key_value_persistence: KeyValuePersistence) -> Self {
+    pub(crate) fn new(roots: Roots<AnyFile>, key_value_persistence: KeyValuePersistence) -> Self {
         let (background_sender, background_receiver) = watch::channel(None);
         let key_value_state = Arc::new(Mutex::new(keyvalue::KeyValueState::new(
             key_value_persistence,
